Documentation
¶
Index ¶
- func CommonPrefix(sep byte, paths ...string) string
- func Copy(afs afero.Fs, src, dst string, fileMode, dirMode fs.FileMode) error
- func CopyDir(afs afero.Fs, source, dest string, fileMode, dirMode fs.FileMode) error
- func CopyFile(afs afero.Fs, source, dest string, fileMode, dirMode fs.FileMode) error
- func MoveFile(afs afero.Fs, src, dst string, fileMode, dirMode fs.FileMode) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CommonPrefix ¶
CommonPrefix returns common directory path of provided files
func CopyDir ¶
CopyDir copies a directory from source to dest and all of its sub-directories. It doesn't stop if it finds an error during the copy. Returns an error if any.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.